@@ -1,7 +1,5 @@
 module FriendlyId
-
   module FinderMethods
-
     # Finds a record using the given id.
     #
     # If the id is "unfriendly", it will call the original find method.
@@ -9,19 +7,33 @@ module FriendlyId
     # id matching '123' and then fall back to looking for a record with the
     # numeric id '123'.
     #
+    # @param [Boolean] allow_nil (default: false)
+    # Use allow_nil: true if you'd like the finder to return nil instead of
+    # raising ActivRecord::RecordNotFound
+    #
+    # ### Example
+    #
+    #     MyModel.friendly.find("bad-slug")
+    #     #=> raise ActiveRecord::RecordNotFound
+    #
+    #     MyModel.friendly.find("bad-slug", allow_nil: true)
+    #     #=> nil
+    #
     # Since FriendlyId 5.0, if the id is a nonnumeric string like '123-foo' it
     # will *only* search by friendly id and not fall back to the regular find
     # method.
     #
     # If you want to search only by the friendly id, use {#find_by_friendly_id}.
     # @raise ActiveRecord::RecordNotFound
-    def find(*args)
+    def find(*args, allow_nil: false)
       id = args.first
-      return super if args.count != 1 || id.unfriendly_id?
-      first_by_friendly_id(id).tap {|result| return result unless result.nil?}
-      return super if potential_primary_key?(id)
+      return super(*args) if args.count != 1 || id.unfriendly_id?
+      first_by_friendly_id(id).tap { |result| return result unless result.nil? }
+      return super(*args) if potential_primary_key?(id)
 
-      raise_not_found_exception(id)
+      raise_not_found_exception(id) unless allow_nil
+    rescue ActiveRecord::RecordNotFound => exception
+      raise exception unless allow_nil
     end
 
     # Returns true if a record with the given id exists.
@@ -35,7 +47,7 @@ module FriendlyId
     # `find`.
     # @raise ActiveRecord::RecordNotFound
     def find_by_friendly_id(id)
-      first_by_friendly_id(id) or raise raise_not_found_exception(id)
+      first_by_friendly_id(id) or raise_not_found_exception(id)
     end
 
     def exists_by_friendly_id?(id)
@@ -50,7 +62,11 @@ module FriendlyId
       key_type = key_type.type if key_type.respond_to?(:type)
       case key_type
       when :integer
-        Integer(id, 10) rescue false
+        begin
+          Integer(id, 10)
+        rescue
+          false
+        end
       when :uuid
         id.match(/\A[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}\z/)
       else
@@ -97,12 +113,11 @@ module FriendlyId
 
     def raise_not_found_exception(id)
       message = "can't find record with friendly id: #{id.inspect}"
-      if ActiveRecord.version < Gem::Version.create('5.0')
+      if ActiveRecord.version < Gem::Version.create("5.0")
         raise ActiveRecord::RecordNotFound.new(message)
       else
         raise ActiveRecord::RecordNotFound.new(message, name, friendly_id_config.query_field, id)
       end
     end
-
   end
 end
