@@ -1,33 +1,33 @@
 require "bundler/setup"
 
-if ENV['COVERALLS'] || ENV['COVERAGE']
-  require 'simplecov'
-  if ENV['COVERALLS']
-    require 'coveralls'
+if ENV["COVERALLS"] || ENV["COVERAGE"]
+  require "simplecov"
+  if ENV["COVERALLS"]
+    require "coveralls"
     SimpleCov.formatter = Coveralls::SimpleCov::Formatter
   end
   SimpleCov.start do
-    add_filter 'test'
-    add_filter 'friendly_id/migration'
+    add_filter "test"
+    add_filter "friendly_id/migration"
   end
 end
 
 begin
-  require 'minitest'
+  require "minitest"
 rescue LoadError
-  require 'minitest/unit'
+  require "minitest/unit"
 end
 
 begin
-  TestCaseClass = MiniTest::Test
+  TestCaseClass = Minitest::Test
 rescue NameError
-  TestCaseClass = MiniTest::Unit::TestCase
+  TestCaseClass = Minitest::Unit::TestCase
 end
 
-require "mocha/setup"
+require "mocha/minitest"
 require "active_record"
-require 'active_support/core_ext/time/conversions'
-require 'erb'
+require "active_support/core_ext/time/conversions"
+require "erb"
 
 I18n.enforce_available_locales = false
 
@@ -39,29 +39,32 @@ if ENV["LOG"]
   ActiveRecord::Base.logger = Logger.new($stdout)
 end
 
-if ActiveSupport::VERSION::STRING >= '4.2'
+if ActiveSupport::VERSION::STRING >= "4.2"
   ActiveSupport.test_order = :random
 end
 
 module FriendlyId
   module Test
-
     def self.included(base)
       if Minitest.respond_to?(:autorun)
         Minitest.autorun
       else
-        require 'minitest/autorun'
+        require "minitest/autorun"
       end
     rescue LoadError
     end
 
     def transaction
-      ActiveRecord::Base.transaction { yield ; raise ActiveRecord::Rollback }
+      ActiveRecord::Base.transaction do
+        yield
+
+        raise ActiveRecord::Rollback
+      end
     end
 
     def with_instance_of(*args)
       model_class = args.shift
-      args[0] ||= {:name => "a b c"}
+      args[0] ||= {name: "a b c"}
       transaction { yield model_class.create!(*args) }
     end
 
@@ -70,7 +73,11 @@ module FriendlyId
 
       def connect
         version = ActiveRecord::VERSION::STRING
-        engine  = RUBY_ENGINE rescue "ruby"
+        engine = begin
+          RUBY_ENGINE
+        rescue
+          "ruby"
+        end
 
         ActiveRecord::Base.establish_connection config[driver]
         message = "Using #{engine} #{RUBY_VERSION} AR #{version} with #{driver}"
@@ -86,7 +93,7 @@ module FriendlyId
       end
 
       def config
-        @config ||= YAML::load(
+        @config ||= YAML.safe_load(
           ERB.new(
             File.read(File.expand_path("../databases.yml", __FILE__))
           ).result
@@ -94,9 +101,9 @@ module FriendlyId
       end
 
       def driver
-        _driver = ENV.fetch('DB', 'sqlite3').downcase
-        _driver = "postgres" if %w(postgresql pg).include?(_driver)
-        _driver
+        db_driver = ENV.fetch("DB", "sqlite3").downcase
+        db_driver = "postgres" if %w[postgresql pg].include?(db_driver)
+        db_driver
       end
 
       def in_memory?
@@ -115,4 +122,4 @@ end
 require "schema"
 require "shared"
 FriendlyId::Test::Database.connect
-at_exit {ActiveRecord::Base.connection.disconnect!}
+at_exit { ActiveRecord::Base.connection.disconnect! }
