@@ -1,4 +1,4 @@
-require 'helper'
+require "helper"
 
 class NumericSlugTest < TestCaseClass
   include FriendlyId::Test
@@ -10,21 +10,21 @@ class NumericSlugTest < TestCaseClass
 
   test "should generate numeric slugs" do
     transaction do
-      record = model_class.create! :name => "123"
+      record = model_class.create! name: "123"
       assert_equal "123", record.slug
     end
   end
 
   test "should find by numeric slug" do
     transaction do
-      record = model_class.create! :name => "123"
+      record = model_class.create! name: "123"
       assert_equal model_class.friendly.find("123").id, record.id
     end
   end
 
   test "should exist? by numeric slug" do
     transaction do
-      record = model_class.create! :name => "123"
+      model_class.create! name: "123"
       assert model_class.friendly.exists?("123")
     end
   end
