@@ -1,7 +1,6 @@
 module FriendlyId
   module Test
     module Shared
-
       module Slugged
         test "configuration should have a sequence_separator" do
           assert !model_class.friendly_id_config.sequence_separator.empty?
@@ -18,15 +17,15 @@ module FriendlyId
 
         test "should add a UUID for duplicate friendly ids" do
           with_instance_of model_class do |record|
-            record2 = model_class.create! :name => record.name
-            assert record2.friendly_id.match(/([0-9a-z]+\-){4}[0-9a-z]+\z/)
+            record2 = model_class.create! name: record.name
+            assert record2.friendly_id.match(/([0-9a-z]+-){4}[0-9a-z]+\z/)
           end
         end
 
         test "should not add slug sequence on update after other conflicting slugs were added" do
           with_instance_of model_class do |record|
             old = record.friendly_id
-            model_class.create! :name => record.name
+            model_class.create! name: record.name
             record.save!
             record.reload
             assert_equal old, record.to_param
@@ -35,7 +34,7 @@ module FriendlyId
 
         test "should not change the sequence on save" do
           with_instance_of model_class do |record|
-            record2 = model_class.create! :name => record.name
+            record2 = model_class.create! name: record.name
             friendly_id = record2.friendly_id
             record2.active = !record2.active
             record2.save!
@@ -64,7 +63,7 @@ module FriendlyId
           with_instance_of my_model_class do |record|
             record.update my_model_class.friendly_id_config.slug_column => nil
             record = my_model_class.friendly.find(record.id)
-            record.class.validate Proc.new {errors.add(:name, "FAIL")}
+            record.class.validate proc { errors.add(:name, "FAIL") }
             record.save
             assert_equal record.to_param, record.friendly_id
           end
@@ -84,7 +83,7 @@ module FriendlyId
         end
 
         test "should be findable by friendly id" do
-          with_instance_of(model_class) {|record| assert model_class.friendly.find record.friendly_id}
+          with_instance_of(model_class) { |record| assert model_class.friendly.find record.friendly_id }
         end
 
         test "should exist? by friendly id" do
@@ -92,19 +91,19 @@ module FriendlyId
             assert model_class.friendly.exists? record.id
             assert model_class.friendly.exists? record.id.to_s
             assert model_class.friendly.exists? record.friendly_id
-            assert model_class.friendly.exists?({:id => record.id})
-            assert model_class.friendly.exists?(['id = ?', record.id])
+            assert model_class.friendly.exists?({id: record.id})
+            assert model_class.friendly.exists?(["id = ?", record.id])
             assert !model_class.friendly.exists?(record.friendly_id + "-hello")
             assert !model_class.friendly.exists?(0)
           end
         end
 
         test "should be findable by id as integer" do
-          with_instance_of(model_class) {|record| assert model_class.friendly.find record.id.to_i}
+          with_instance_of(model_class) { |record| assert model_class.friendly.find record.id.to_i }
         end
 
         test "should be findable by id as string" do
-          with_instance_of(model_class) {|record| assert model_class.friendly.find record.id.to_s}
+          with_instance_of(model_class) { |record| assert model_class.friendly.find record.id.to_s }
         end
 
         test "should treat numeric part of string as an integer id" do
@@ -116,16 +115,16 @@ module FriendlyId
         end
 
         test "should be findable by numeric friendly_id" do
-          with_instance_of(model_class, :name => "206") {|record| assert model_class.friendly.find record.friendly_id}
+          with_instance_of(model_class, name: "206") { |record| assert model_class.friendly.find record.friendly_id }
         end
 
         test "to_param should return the friendly_id" do
-          with_instance_of(model_class) {|record| assert_equal record.friendly_id, record.to_param}
+          with_instance_of(model_class) { |record| assert_equal record.friendly_id, record.to_param }
         end
 
         if ActiveRecord::VERSION::MAJOR == 4 && ActiveRecord::VERSION::MINOR < 2
           test "should be findable by themselves" do
-            with_instance_of(model_class) {|record| assert_equal record, model_class.friendly.find(record)}
+            with_instance_of(model_class) { |record| assert_equal record, model_class.friendly.find(record) }
           end
         end
 
@@ -138,11 +137,11 @@ module FriendlyId
         end
 
         test "instances found by a single id should not be read-only" do
-          with_instance_of(model_class) {|record| assert !model_class.friendly.find(record.friendly_id).readonly?}
+          with_instance_of(model_class) { |record| assert !model_class.friendly.find(record.friendly_id).readonly? }
         end
 
         test "failing finds with unfriendly_id should raise errors normally" do
-          assert_raises(ActiveRecord::RecordNotFound) {model_class.friendly.find 0}
+          assert_raises(ActiveRecord::RecordNotFound) { model_class.friendly.find 0 }
         end
 
         test "should return numeric id if the friendly_id is nil" do
